summaryrefslogtreecommitdiffstats
path: root/views/view.h
diff options
context:
space:
mode:
Diffstat (limited to 'views/view.h')
-rw-r--r--views/view.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/views/view.h b/views/view.h
index 03291c6..967ce22 100644
--- a/views/view.h
+++ b/views/view.h
@@ -1127,9 +1127,11 @@ class View : public AcceleratorTarget {
void PrintViewHierarchyImp(int indent);
void PrintFocusHierarchyImp(int indent);
- // Registers/unregister this view's keyboard accelerators with the
- // FocusManager.
- void RegisterAccelerators();
+ // Registers this view's keyboard accelerators that are not registered to
+ // FocusManager yet, if possible.
+ void RegisterPendingAccelerators();
+
+ // Unregisters all the keyboard accelerators associated with this view.
void UnregisterAccelerators();
// This View's bounds in the parent coordinate system.
@@ -1174,8 +1176,11 @@ class View : public AcceleratorTarget {
// Next view to be focused when the Shift-Tab key combination is pressed.
View* previous_focusable_view_;
- // The list of accelerators.
+ // The list of accelerators. List elements in the range
+ // [0, registered_accelerator_count_) are already registered to FocusManager,
+ // and the rest are not yet.
scoped_ptr<std::vector<Accelerator> > accelerators_;
+ int registered_accelerator_count_;
// The menu controller.
ContextMenuController* context_menu_controller_;